@@ -24,7 +24,7 @@ Readonly my $FALSE   => 0;
 Readonly my $EMPTY   => q{};
 Readonly my $NL      => "\n";
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 our %DEFAULT_PROCESSORS = (
   pre       => \&_pre,
@@ -188,6 +188,10 @@ sub process_file {
     }
   } ## end LINE: while (1)
 
+  if ($EVAL_ERROR) {
+    croak "$EVAL_ERROR";
+  }
+
   return $processors{'post'}->( $fh, $all_lines, \%args );
 } ## end sub process_file
 
